@@ -2,6 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
 from decimal import Decimal
+from trytond.transaction import Transaction
 
 
 class Move(ModelSQL, ModelView):
@@ -120,8 +121,9 @@ class Move(ModelSQL, ModelView):
         account_move_lines.append(
                 self._get_account_stock_move_line(move, amount))
 
-        account_move_id = account_move_obj.create(
-                self._get_account_stock_move(move, account_move_lines, type_))
+        with Transaction().set_user(0, set_context=True):
+            account_move_id = account_move_obj.create(
+                    self._get_account_stock_move(move, account_move_lines, type_))
         self.write(move.id, {
             'account_move': account_move_id,
             })
